@@ -1,4 +1,4 @@
-from typing import Any, cast, Dict, List, Optional, TYPE_CHECKING, Union
+from typing import Any, cast, List, Optional, TYPE_CHECKING, Union
 
 from gitlab import exceptions as exc
 from gitlab.base import RESTManager, RESTObject
@@ -54,6 +54,7 @@ class ProjectApprovalManager(GetWithoutIdMixin, UpdateMixin, RESTManager):
 
 class ProjectApprovalRule(SaveMixin, ObjectDeleteMixin, RESTObject):
     _id_attr = "id"
+    _repr_attr = "name"
 
 
 class ProjectApprovalRuleManager(
@@ -89,6 +90,8 @@ class ProjectMergeRequestApprovalManager(GetWithoutIdMixin, UpdateMixin, RESTMan
         approver_ids: Optional[List[int]] = None,
         approver_group_ids: Optional[List[int]] = None,
         approval_rule_name: str = "name",
+        *,
+        approver_usernames: Optional[List[str]] = None,
         **kwargs: Any,
     ) -> RESTObject:
         """Change MR-level allowed approvers and approver groups.
@@ -104,6 +107,7 @@ class ProjectMergeRequestApprovalManager(GetWithoutIdMixin, UpdateMixin, RESTMan
         """
         approver_ids = approver_ids or []
         approver_group_ids = approver_group_ids or []
+        approver_usernames = approver_usernames or []
 
         data = {
             "name": approval_rule_name,
@@ -111,6 +115,7 @@ class ProjectMergeRequestApprovalManager(GetWithoutIdMixin, UpdateMixin, RESTMan
             "rule_type": "regular",
             "user_ids": approver_ids,
             "group_ids": approver_group_ids,
+            "usernames": approver_usernames,
         }
         if TYPE_CHECKING:
             assert self._parent is not None
@@ -118,12 +123,13 @@ class ProjectMergeRequestApprovalManager(GetWithoutIdMixin, UpdateMixin, RESTMan
             self._parent.approval_rules
         )
         # update any existing approval rule matching the name
-        existing_approval_rules = approval_rules.list()
+        existing_approval_rules = approval_rules.list(iterator=True)
         for ar in existing_approval_rules:
             if ar.name == approval_rule_name:
                 ar.user_ids = data["user_ids"]
                 ar.approvals_required = data["approvals_required"]
                 ar.group_ids = data["group_ids"]
+                ar.usernames = data["usernames"]
                 ar.save()
                 return ar
         # if there was no rule matching the rule name, create a new one
@@ -132,53 +138,27 @@ class ProjectMergeRequestApprovalManager(GetWithoutIdMixin, UpdateMixin, RESTMan
 
 class ProjectMergeRequestApprovalRule(SaveMixin, ObjectDeleteMixin, RESTObject):
     _repr_attr = "name"
-    id: int
-    approval_rule_id: int
-    merge_request_iid: int
-
-    @exc.on_http_error(exc.GitlabUpdateError)
-    def save(self, **kwargs: Any) -> None:
-        """Save the changes made to the object to the server.
-
-        The object is updated to match what the server returns.
-
-        Args:
-            **kwargs: Extra options to send to the server (e.g. sudo)
-
-        Raise:
-            GitlabAuthenticationError: If authentication is not correct
-            GitlabUpdateError: If the server cannot perform the request
-        """
-        # There is a mismatch between the name of our id attribute and the put
-        # REST API name for the project_id, so we override it here.
-        self.approval_rule_id = self.id
-        self.merge_request_iid = self._parent_attrs["mr_iid"]
-        self.id = self._parent_attrs["project_id"]
-        # save will update self.id with the result from the server, so no need
-        # to overwrite with what it was before we overwrote it.
-        SaveMixin.save(self, **kwargs)
 
 
 class ProjectMergeRequestApprovalRuleManager(CRUDMixin, RESTManager):
-    _path = "/projects/{project_id}/merge_requests/{mr_iid}/approval_rules"
+    _path = "/projects/{project_id}/merge_requests/{merge_request_iid}/approval_rules"
     _obj_cls = ProjectMergeRequestApprovalRule
-    _from_parent_attrs = {"project_id": "project_id", "mr_iid": "iid"}
+    _from_parent_attrs = {"project_id": "project_id", "merge_request_iid": "iid"}
     _update_attrs = RequiredOptional(
         required=(
             "id",
             "merge_request_iid",
-            "approval_rule_id",
             "name",
             "approvals_required",
         ),
-        optional=("user_ids", "group_ids"),
+        optional=("user_ids", "group_ids", "usernames"),
     )
     # Important: When approval_project_rule_id is set, the name, users and
     # groups of project-level rule will be copied. The approvals_required
     # specified will be used.
     _create_attrs = RequiredOptional(
-        required=("id", "merge_request_iid", "name", "approvals_required"),
-        optional=("approval_project_rule_id", "user_ids", "group_ids"),
+        required=("name", "approvals_required"),
+        optional=("approval_project_rule_id", "user_ids", "group_ids", "usernames"),
     )
 
     def get(
@@ -188,32 +168,6 @@ class ProjectMergeRequestApprovalRuleManager(CRUDMixin, RESTManager):
             ProjectMergeRequestApprovalRule, super().get(id=id, lazy=lazy, **kwargs)
         )
 
-    def create(
-        self, data: Optional[Dict[str, Any]] = None, **kwargs: Any
-    ) -> RESTObject:
-        """Create a new object.
-
-        Args:
-            data: Parameters to send to the server to create the
-                         resource
-            **kwargs: Extra options to send to the server (e.g. sudo or
-                      'ref_name', 'stage', 'name', 'all')
-
-        Raises:
-            GitlabAuthenticationError: If authentication is not correct
-            GitlabCreateError: If the server cannot perform the request
-
-        Returns:
-            A new instance of the manage object class build with
-                the data sent by the server
-        """
-        if TYPE_CHECKING:
-            assert data is not None
-        new_data = data.copy()
-        new_data["id"] = self._from_parent_attrs["project_id"]
-        new_data["merge_request_iid"] = self._from_parent_attrs["mr_iid"]
-        return CreateMixin.create(self, new_data, **kwargs)
-
 
 class ProjectMergeRequestApprovalState(RESTObject):
     pass
